﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using VeterinaryBusinessLogic.OfficePackage.HelperEnums;
using VeterinaryBusinessLogic.OfficePackage.HelperModels;

namespace VeterinaryBusinessLogic.OfficePackage
{
	public abstract class AbstractSaveToExcelDoctor
	{
		public void CreateReport(ExcelInfoDoctor info)
		{
			CreateExcel(info);

			InsertCellInWorksheet(new ExcelCellParameters
			{
				ColumnName = "A",
				RowIndex = 1,
				Text = info.Title,
				StyleInfo = ExcelStyleInfoType.Title
			});

			MergeCells(new ExcelMergeParameters
			{
				CellFromName = "A1",
				CellToName = "C1"
			});

			uint rowIndex = 2;

			foreach (var rec in info.PurchaseMedications)
			{
				InsertCellInWorksheet(new ExcelCellParameters
				{
					ColumnName = "A",
					RowIndex = rowIndex,
					Text = rec.MedicationName,
					StyleInfo = ExcelStyleInfoType.Text
				});

				rowIndex++;

				foreach (var medication in rec.Purchases)
				{
					InsertCellInWorksheet(new ExcelCellParameters
					{
						ColumnName = "B",
						RowIndex = rowIndex,
						Text = medication.DateCreate.ToString(),
						StyleInfo = ExcelStyleInfoType.TextWithBroder
					});

					rowIndex++;
				}

				rowIndex++;
			}

			SaveExcel(info);
		}

		protected abstract void CreateExcel(ExcelInfoDoctor info);

		protected abstract void InsertCellInWorksheet(ExcelCellParameters excelParams);

		protected abstract void MergeCells(ExcelMergeParameters excelParams);

		protected abstract void SaveExcel(ExcelInfoDoctor info);
	}
}
